@@ -1,5 +1,5 @@
 #![no_std]
-#![allow(non_camel_case_types, non_upper_case_globals, non_snake_case)]
+#![allow(non_camel_case_types, non_upper_case_globals, non_snake_case, unused_parens)]
 
 pub use crate::boolobject::*;
 pub use crate::bufferobject::*;
